@@ -1,5 +1,5 @@
 import pyutilib.workflow
-import random
+import math
 
 # @class:
 class TaskD(pyutilib.workflow.Task):
@@ -26,9 +26,8 @@ class TaskE(pyutilib.workflow.Task):
 
     def execute(self):
         """Compute the sum of the inputs."""
-        self.Z = random.randint(1,self.Y)
+        self.Z = int(math.floor(self.Y/7.0))
 
-random.seed(123809870128)
 D = TaskD()
 for i in range(100):
     E = TaskE()
@@ -36,5 +35,5 @@ for i in range(100):
 
 w = pyutilib.workflow.Workflow()
 w.add(D)
-print w(Y=100)
+print(w(Y=100))
 # @:usage
