@@ -9,7 +9,7 @@
 
 __all__ = ['Port', 'Ports', 'InputPorts', 'OutputPorts']
 
-from connector import DirectConnector
+from pyutilib.workflow.connector import DirectConnector
 import pprint
 
 
@@ -21,7 +21,7 @@ def define_connection(cls, from_port, to_port):
     # Raise an exception if the port action is store and there already exists a connection.
     #
     if to_port.action == 'store' and len(to_port.input_connections) == 1:
-        raise ValueError, "Cannot connect to task %s port %s from task %s port %s. This port is already connected from task %s port %s" % (to_port.task.name, to_port.name, from_port.task.name, from_port.name, to_port.input_connections[0].from_port.task.name, to_port.input_connections[0].from_port.name)
+        raise ValueError("Cannot connect to task %s port %s from task %s port %s. This port is already connected from task %s port %s" % (to_port.task.name, to_port.name, from_port.task.name, from_port.name, to_port.input_connections[0].from_port.task.name, to_port.input_connections[0].from_port.name))
     #
     #print 'connecting',from_port.task.id, to_port.task.id
     connector = cls(from_port=from_port, to_port=to_port)
@@ -113,15 +113,15 @@ class Port(object):
     def validate(self):
         if self.action in ['store', 'store_any']:
             if not self.optional and self.get_value() is None:
-                raise ValueError, "Task %s Port %s requires a nontrivial value.  Value specified is None." % (str(self.task.id), self.name)
+                raise ValueError("Task %s Port %s requires a nontrivial value.  Value specified is None." % (str(self.task.id), self.name))
         #
         elif self.action in ['append', 'append_any']:
             if not self.optional and self.get_value() is None:
-                raise ValueError, "Task %s Port %s requires a nontrivial value.  All input connections have value None." % (str(self.task.id), self.name)
+                raise ValueError("Task %s Port %s requires a nontrivial value.  All input connections have value None." % (str(self.task.id), self.name))
         #
         elif self.action in ['map', 'map_any']:
             if not self.optional and self.get_value() is None:
-                raise ValueError, "Task %s Port %s requires a nontrivial value.  All input connections have value None." % (str(self.task.id), self.name)
+                raise ValueError("Task %s Port %s requires a nontrivial value.  All input connections have value None." % (str(self.task.id), self.name))
 
     def _repn_(self):
         tmp = {}
@@ -168,7 +168,7 @@ class Port(object):
         #
         # We should never get here.
         #
-        raise IOError, "WARNING: unknown action: "+self.action  #pragma:nocover
+        raise IOError("WARNING: unknown action: "+self.action)  #pragma:nocover
 
     def set_ready(self):
         self._ready=True
@@ -216,7 +216,7 @@ class Ports(dict):
         #print "__setattr__ '%s'" % name,name in self.__dict__,self.__dict__.keys(),dict.keys(self)
         if not name in self.__dict__:
             if not isinstance(val, Port):
-                raise TypeError, "Error declaring port '%s' without a Port object" % name
+                raise TypeError("Error declaring port '%s' without a Port object" % name)
             dict.__setitem__(self, name, val)
             self.__dict__[name] = val
             #print "BUG", name, name in self.__dict__
@@ -236,12 +236,12 @@ class Ports(dict):
         try:
             return self.__dict__.__getitem__(name)
         except:
-            raise AttributeError, "Unknown attribute '%s'" % name
+            raise AttributeError("Unknown attribute '%s'" % name)
 
     def _repn_(self):
         tmp = {}
         tmp['A_TYPE'] = 'Port'
-        for k, v in self.__dict__.iteritems():
+        for k, v in self.__dict__.items():
             if not k.startswith("_"):
                 tmp[k] = v._repn_()
         tmp['Name'] = self._name_
@@ -256,7 +256,7 @@ class Ports(dict):
 
     def __repr__(self):                 #pragma:nocover
         """Return a string representation of these connections."""
-        attrs = sorted("%s = %r" % (k, v) for k, v in self.__dict__.iteritems() if not k.startswith("_"))
+        attrs = sorted("%s = %r" % (k, v) for k, v in self.__dict__.items() if not k.startswith("_"))
         return "%s(%s)" % (self.__class__.__name__, ", ".join(attrs))
 
     def __str__(self, nesting = 1, indent='',print_name=True):
