@@ -11,11 +11,11 @@
 
 __all__ = ['Task', 'EmptyTask', 'Component']
 
-import port
 import argparse
-import globals
-from pyutilib.misc import Options
 import pprint
+from pyutilib.workflow import globals
+from pyutilib.misc import Options
+from pyutilib.workflow import port 
 
 
 class Task(object):
@@ -76,7 +76,7 @@ class Task(object):
            
     def execute(self, debug=False):
         """Execute this task."""
-        raise ValueError, "There is no default execution for an abstract Task object! Task=%s" % str(self) #pragma:nocover
+        raise ValueError("There is no default execution for an abstract Task object! Task=%s" % str(self))  #pragma:nocover
 
     def busy_resources(self):
         """Return the list of resources that this task is waiting for."""
@@ -117,13 +117,13 @@ class Task(object):
         self._call_start()
         busy = self.busy_resources()
         if len(busy) > 0:
-            raise IOError, "Cannot execute task %s.  Busy resources: %s" % (self.name, str(busy))
+            raise IOError("Cannot execute task %s.  Busy resources: %s" % (self.name, str(busy)))
         # Set inputs
         for opt in options:
             self._set_inputs(opt)
         self._set_inputs(kwds)
         #
-        for name, res in self._resources.iteritems():
+        for name, res in self._resources.items():
             res.lock()
         for i in self.outputs:
             #print "z",i,getattr(self.outputs,i).get_value()
@@ -140,7 +140,7 @@ class Task(object):
             # TODO: validate that non-optional outputs have a value other than None
             self.outputs[i].set_value( getattr(self, i) )
 
-        for name, res in self._resources.iteritems():
+        for name, res in self._resources.items():
             res.unlock()
         self._call_finish()
         self.set_ready( )
